/**
  * Aller (le terrier d'AbulEdu)
  *
  * @warning aucun traitement d'erreur n'est pour l'instant implémenté
  * @see https://redmine.ryxeo.com/projects/leterrier-aller
  * @author 2011 Jean-Louis Frucot <frucot.jeanlouis@free.fr>
  * @see The GNU Public License (GPL)
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 * for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef ABULEDUTETEV1_H
#define ABULEDUTETEV1_H

#include <QWidget>
#include <QHBoxLayout>
#include <QMap>

/** @author Jean-Louis Frucot<frucot.jeanlouuis@free.fr>
  * @version 0.9
  *
  */

/** AbulEduTeteV1 affiche sur série d'images (têtes) symbolisant la réussite à un exercice
  * Une tête peut avoir quatre état : Neutre, Bien, Passable, Mal
  * Cette classe retourne une QHBoxLayout comportant n "têtes" Neutres, d'une taille spécifiée ou 51px par défaut
  * Il est possible de modifier l'état de chaque tête et de retrouver son état
  * de même, il est possible de redimensionner les têtes (elles auront toutes la meme taille)
  * Il est possible de spécifier un thème pour les têtes à condition qu'il ait été enregistré
  * dans le fichier de ressources tetes.qrc avec un prefix qui servira à les identifier et pour chacune des quatre images un alias : Neutre, Bien, Passable ou Mal
  */
class AbulEduTeteV1 : public QHBoxLayout
{
    Q_OBJECT
public:
    /** Crée une QHBoxLayout composée de n têtes
      * @param prefixe reférence au groupe de têtes défini dans tetes.qrc
      * @param nbTete le nombre de têtes a afficher (état Neutre au lancement)
      * @param taille en pixel 51 par défaut (les proportions de l'image sont conservées)
      */
    AbulEduTeteV1(QString prefixeTete, int nbTete, int taille = 51, QWidget *parent = 0);

    /** Attribue un état à la tête d'indice numTete
      * @param numTete
      * @param tete 0-> Neutre, 1-> Bien, 2-> Passable, 3-> MAl
      */
    void setEtatTete(int numTete, int tete);

    /** Réaffiche toutes les têtes dans l'état neutre
      * @param prefixe reférence au groupe de têtes défini dans tetes.qrc
      * @param nbTete le nombre de têtes a afficher (état Neutre au lancement)
      */
    void resetTetes(QString prefixeTete, int nbTete, QWidget *parent = 0);

    /** Redimensionne les têtes
      * @param taille la taile en pixel (les proportions de l'image sont conservées)
      */
    void resizeTetes(int taille);

    /** Lis l'état d'une tête
      * @param le numéro de la tête
      * @return le numéro de l'état : 0-> Neutre, 1-> Bien, 2-> Passable, 3-> MAl
      */
    int getEtatTete(int numTete);

    /** Lit l'état de toutes les têtes
      * @return Qlist<int> les numéro de l'état de chaque tête :  0-> Neutre, 1-> Bien, 2-> Passable, 3-> MAl
      */
    QList<int> getEtatTetes();

    QMap<int, QString> *suffixe;
private:

    QList<int> m_listeTetes;
    QString m_prefixe;
    QSize m_taille;
};

#endif // ABULEDUTETEV1_H
